#!/bin/sh

# OpenVAS
# $Id$
# Description: Script for checking for missing plugins/.inc files.
# Go to the scripts directory, e.g. openvas-plugins/scripts
# and execute the script.
#
# Authors:
# Jan-Oliver Wagner <jan-oliver.wagner@intevation.de>
#
# Copyright:
# Copyright (C) 2007 Intevation GmbH
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2,
# as published by the Free Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

# First check: Are some included files not present but needed by others?

grep "include(" *.nasl *.inc | sed -e "s/:.*include([\"']/ /g" -e "s/[\"']);.*$//" | grep -v "include()" | sort -k 2 > /tmp/check-dep1.tmp
ls *.inc | sort > /tmp/check-dep2.tmp
echo
echo "Unused NASL-Plugins due to missing .inc-files:"
echo "----------------------------------------------"
join -1 2 -2 1 -v 1 /tmp/check-dep1.tmp /tmp/check-dep2.tmp | sed -e "s/^\(.*\) \(.*\)$/\2 requires \1/"
echo

echo ".inc-files that are never included:"
echo "-----------------------------------"
join -1 2 -2 1 -v 2 /tmp/check-dep1.tmp /tmp/check-dep2.tmp
echo

# Second check: Are some files declared as dependency but not present?
grep "\"*..nasl\"" * | tr "," "\n" | grep  "\""  | grep -v "Services/www" | sed -e "s/^.*://" -e "s/^.*\"\(.*\)\".*$/\1/" | sort | grep -v "^ *$" | grep -v "find_service.nes" > /tmp/check-dep3.tmp
ls | sort > /tmp/check-dep4.tmp
join -v 1 /tmp/check-dep3.tmp /tmp/check-dep4.tmp > /tmp/check-dep5.tmp

echo
echo "Top-List on how many NASL-Plugins could potentially be made active by adding missing dependency"
echo "-----------------------------------------------------------------------------------------------"
uniq -c /tmp/check-dep5.tmp | sort -n -r

echo
echo "Number of unused NASL-Plugins due to missing dependencies:"
echo "----------------------------------------------------------"
grep -n -f /tmp/check-dep6.tmp  * | sed -e "s/:.*$//" | uniq | wc -l
echo "Out of:"
ls *.nasl | wc -l

echo
echo "Unused NASL-Plugins due to missing dependencies:"
echo "------------------------------------------------"
uniq /tmp/check-dep5.tmp > /tmp/check-dep6.tmp
grep -n -f /tmp/check-dep6.tmp  *
